==> tutti-ui-swing-2.3.3-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolBenthosAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportProtocolBenthosAction.java 739 2013-04-05 13:36:16Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.3.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolBenthosAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.persistence.entities.protocol.SpeciesProtocol;
import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;
import java.util.List;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol benthos.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportProtocolBenthosAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ImportProtocolBenthosAction.class);

    private File file;

    public ImportProtocolBenthosAction(EditProtocolUIHandler handler) {
        super(handler, false);
    }

    @Override
    protected boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to import
            file = TuttiUIUtil.chooseFile(
                    getContext().getMainUI(),
                    _("tutti.editProtocol.title.choose.benthosImportFile"),
                    _("tutti.editProtocol.action.chooseProtocolBenthosFile"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );

            doAction = file != null;
        }
        return doAction;
    }

    @Override
    protected void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    protected void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will import protocol benthos file: " + file);
        }

        EditProtocolUIModel model = getModel();

        // bind to a protocol
        TuttiProtocol protocol = model.toBean();

        // import
        TuttiProtocolImportExportService service =
                getContext().getTuttiProtocolImportExportService();

        service.importProtocolBenthos(file,
                                      protocol,
                                      model.getAllCaracteristic(),
                                      model.getAllReferentSpeciesByTaxonId());

        // build rows from imported+merged protocol
        // (will also remove all synonyms of species referent used)
        List<EditProtocolSpeciesRowModel> rows =
                handler.toRows(protocol.getBenthos());

        // update species comboBox
//        getUI().getSpeciesComboBox().getHandler().sortData();
        getUI().getSpeciesComboBox().getHandler().reset();

        // update benthos comboBox
//        getUI().getBenthosComboBox().getHandler().sortData();
        getUI().getBenthosComboBox().getHandler().reset();

        // update rows in model
        model.setBenthosRow(rows);

        getHandler().getBenthosTableModel().setRows(rows);

        int nbSynonym = 0;
        for (SpeciesProtocol speciesProtocol : protocol.getBenthos()) {
            if (!speciesProtocol.isMadeFromAReferentTaxon()) {
                nbSynonym++;
            }
        }

        String message;
        switch (nbSynonym) {
            case 0:
                message = _("tutti.flash.info.benthos.imported.in.protocol",
                            file);
                break;

            case 1:
                message = _("tutti.flash.info.benthos.imported.in.protocol.oneReplaced",
                            file);
                break;

            default:
                message = _("tutti.flash.info.benthos.imported.in.protocol.severalReplaced",
                            file, nbSynonym);
        }
        sendMessage(message);
    }
}

==> tutti-ui-swing-2.4-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolBenthosAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportProtocolBenthosAction.java 1170 2013-09-13 16:21:34Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.4/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolBenthosAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.persistence.entities.protocol.SpeciesProtocol;
import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;
import java.util.List;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol benthos.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportProtocolBenthosAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ImportProtocolBenthosAction.class);

    private File file;

    public ImportProtocolBenthosAction(EditProtocolUIHandler handler) {
        super(handler, false);
    }

    @Override
    public boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to import
            file = chooseFile(
                    _("tutti.editProtocol.title.choose.benthosImportFile"),
                    _("tutti.editProtocol.action.chooseProtocolBenthosFile"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );

            doAction = file != null;
        }
        return doAction;
    }

    @Override
    public void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    public void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will import protocol benthos file: " + file);
        }

        EditProtocolUIModel model = getModel();

        // bind to a protocol
        TuttiProtocol protocol = model.toBean();

        // import
        TuttiProtocolImportExportService service =
                getContext().getTuttiProtocolImportExportService();

        service.importProtocolBenthos(file,
                                      protocol,
                                      model.getAllCaracteristic(),
                                      model.getAllReferentSpeciesByTaxonId());

        // build rows from imported+merged protocol
        // (will also remove all synonyms of species referent used)
        List<EditProtocolSpeciesRowModel> rows =
                handler.toRows(protocol.getBenthos());

        // update species comboBox
        getUI().getSpeciesComboBox().getHandler().reset();

        // update benthos comboBox
        getUI().getBenthosComboBox().getHandler().reset();

        // update rows in model
        model.setBenthosRow(rows);

        getHandler().getBenthosTableModel().setRows(rows);

        int nbSynonym = 0;
        for (SpeciesProtocol speciesProtocol : protocol.getBenthos()) {
            if (!speciesProtocol.isMadeFromAReferentTaxon()) {
                nbSynonym++;
            }
        }

        String message;
        switch (nbSynonym) {
            case 0:
                message = _("tutti.flash.info.benthos.imported.in.protocol",
                            file);
                break;

            case 1:
                message = _("tutti.flash.info.benthos.imported.in.protocol.oneReplaced",
                            file);
                break;

            default:
                message = _("tutti.flash.info.benthos.imported.in.protocol.severalReplaced",
                            file, nbSynonym);
        }
        sendMessage(message);
    }
}
